@@ -5,11 +5,12 @@ from typing import *
 
 from cognite.seismic._api.api import API
 from cognite.seismic._api.utility import LineRange, MaybeString, get_identifier
+from cognite.seismic.data_classes.api_types import Trace
 
 if not os.getenv("READ_THE_DOCS"):
     from cognite.seismic.protos.v1.seismic_service_messages_pb2 import VolumeRequest
-    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import Seismic, OptionalMap, LineBasedVolume
-    from cognite.seismic.protos.types_pb2 import Geometry as GeometryProto, Wkt, GeoJson, Trace, LineDescriptor
+    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import OptionalMap, LineBasedVolume
+    from cognite.seismic.protos.types_pb2 import Geometry as GeometryProto, Wkt, GeoJson, LineDescriptor
     from google.protobuf.wrappers_pb2 import StringValue, Int32Value as i32
 
 
@@ -52,7 +53,9 @@ class VolumeSeismicAPI(API):
             req.seismic_store_id = seismic_store_id
         else:
             req.seismic.MergeFrom(get_identifier(id, external_id))
-        return self.query.GetVolume(req, metadata=self.metadata)
+
+        for proto in self.query.GetVolume(req, metadata=self.metadata):
+            yield Trace.from_proto(proto)
 
 
 def into_line_range(linerange: Optional[LineRange]) -> LineDescriptor:
